use ::levels::Levels;
use ::logger::Logger;
use ::record::Record;



/// This is a fake Logger.
///
/// No domains or severity Levels are enabled,
/// and all logging calls are ignored.
pub struct FauxLogger;



// The fake Logger will do nothing if this is built
// to just use the core library.
#[cfg(not(feature="use_std"))]
impl Logger for FauxLogger
{
   fn is_domain_enabled(&self, _domain_name: &'static str) -> bool
   {
      false
   }

   fn is_level_enabled(&self, _lvl: Levels) -> bool
   {
      false
   }

   fn log(&self, _record: &Record)
   {
   }
}

// When built using the STD library, the fake Logger will
// act as a simple console printer. This is to make development easier.
#[cfg(feature="use_std")]
impl Logger for FauxLogger
{
   fn is_domain_enabled(&self, _domain_name: &'static str) -> bool
   {
      true
   }

   fn is_level_enabled(&self, _lvl: Levels) -> bool
   {
      true
   }

   fn log(&self, record: &Record)
   {
      println!("{}", record);
   }
}
